@@ -1,13 +1,13 @@
 package Data::Cmp;
 
 our $DATE = '2018-08-12'; # DATE
-our $VERSION = '0.002'; # VERSION
+our $VERSION = '0.003'; # VERSION
 
 use 5.010001;
 use strict;
 use warnings;
 
-use Scalar::Util qw(looks_like_number blessed reftype refaddr);
+use Scalar::Util qw(blessed reftype refaddr);
 
 require Exporter;
 our @ISA = qw(Exporter);
@@ -105,7 +105,7 @@ Data::Cmp - Compare two data structures, return -1/0/1 like cmp
 
 =head1 VERSION
 
-This document describes version 0.002 of Data::Cmp (from Perl distribution Data-Cmp), released on 2018-08-12.
+This document describes version 0.003 of Data::Cmp (from Perl distribution Data-Cmp), released on 2018-08-12.
 
 =head1 SYNOPSIS
 
@@ -126,17 +126,15 @@ This document describes version 0.002 of Data::Cmp (from Perl distribution Data-
 
 Sort data structures (of similar structures):
 
- use Data::Cmp qw(cmp_data);
- use Data::Dump;
- my @arrays = ([3], [1], [-1, 2], [0,0], [1,2]);
- dd sort { cmp_data($a, $b) } @arrays;
+ my @arrays = (["c"], ["b"], ["a", "b"], ["a"], ["a","c"]);
+ my @sorted = sort { cmp_data($a, $b) } @arrays; # => (["a"], ["a","b"], ["a","c"], ["b"], ["c"])
 
 =head1 DESCRIPTION
 
 This relatively compact module offers the C<cmp_data> function that, like Perl's
 C<cmp>, returns -1/0/1 value. In addition to that, it can also return 2 if the
 two data structures differ but there is no sensible notion of which one is
-larger than the other.
+"greater than" the other.
 
 This module can handle circular structure.
 
@@ -144,25 +142,47 @@ The following are the rules of comparison used by C<cmp_data()>:
 
 =over
 
-=item * Two undefs are the same (0)
+=item * Two undefs are the same
 
-=item * A defined value is greater than (1) undef
+=item * A defined value is greater than undef
 
 =item * Two non-reference scalars are compared string-wise using Perl's cmp
 
-=item * A reference and non-reference are different (2)
+=item * A reference and non-reference are different
 
-=item * Two references that are of different types are different (2)
+ cmp_data([], 0); # 2
 
-=item * Blessed references that are blessed into different packages are different (2)
+=item * Two references that are of different types are different
 
-=item * Array references are compared element by element
+ cmp_data([], {}); # 2
 
-=item * A longer array is greater than (1) its shorter subset
+=item * Blessed references that are blessed into different packages are different
 
-=item * Hash references are compared key by key
+ cmp_data(bless([], "foo"), bless([], "bar")); # 2
+ cmp_data(bless([], "foo"), bless([], "foo")); # 0
 
-=item * When two hash references share a common subset of pairs, the greater is the one that has more non-common pairs
+=item * Two array references are compared element by element
+
+ cmp_data(["a","b","c"], ["a","b","c"]); #  0
+ cmp_data(["a","b","c"], ["a","b","d"]); # -1
+ cmp_data(["a","d","c"], ["a","b","e"]); #  1
+
+=item * A longer arrayref is greater than its shorter subset
+
+ cmp_data(["a","b"], ["a"]); # 1
+
+=item * Two hash references are compared key by key
+
+ cmp_data({k1=>"a", k2=>"b", k3=>"c"}, {k1=>"a", k2=>"b", k3=>"d"}); # 0
+ cmp_data({k1=>"a", k2=>"b", k3=>"c"}, {k1=>"a", k2=>"b", k3=>"c"}); # 1
+
+=item * When two hash references share a common subset of pairs but have non-common pairs, the greater hashref is the one that has more non-common pairs
+
+If the number of non-common pairs are the same, they are just different.
+
+ cmp_data({k1=>"", k2=>"", k3=>""}, {k1=>"", k5=>""});                #  1
+ cmp_data({k1=>"", k2=>"", k3=>""}, {k1=>"", k5=>"", k6=>"});         #  2
+ cmp_data({k1=>"", k2=>"", k3=>""}, {k1=>"", k5=>"", k6=>", k7=>""}); # -1
 
 =back
 
@@ -192,9 +212,9 @@ feature.
 
 =head1 SEE ALSO
 
-Other variants of Data::Cmp: C<Data::Cmp::Custom> (allows custom actions and
-comparison routines), C<Data::Cmp::Diff> (generates diff structure instead of
-just returning -1/0/1/2), C<Data::Cmp::Diff::Perl> (generates diff in the form
+Other variants of Data::Cmp: L<Data::Cmp::Custom> (allows custom actions and
+comparison routines), L<Data::Cmp::Diff> (generates diff structure instead of
+just returning -1/0/1/2), L<Data::Cmp::Diff::Perl> (generates diff in the form
 of Perl code).
 
 Modules that just return boolean result ("same or different"): L<Data::Compare>,
